from typing import Tuple, List, Optional

import click

from vs_starter.config import render_config


class KeyValueParamType(click.ParamType):
    name = "KEY=VALUE"

    def convert(
        self, value: str, param: Optional[click.Parameter], ctx: Optional[click.Context]
    ) -> List[str]:
        if not "=" in value:
            raise ValueError("Params have to be provided in the form key=value")

        return value.split("=")


KEY_VALUE = KeyValueParamType()


@click.command()
@click.argument("helm_config_path")
@click.argument("output_path")
@click.option(
    "--param",
    "-p",
    help="""parameters for the jinja templates [slug, service_url, 
            release_version, sftp,
            shibauth_renderer, shibauth_cache]""",
    type=KEY_VALUE,
    required=True,
    multiple=True,
)
def cli(helm_config_path: str, output_path: str, param: Tuple[Tuple[str, str]]) -> None:
    normalized_params = {}
    for k, v in param:
        normalized_params[k] = v
    render_config(helm_config_path, output_path, normalized_params)
